package com.glxp.mipsdl.admin.client.http;

import cn.hutool.core.util.StrUtil;
import com.alibaba.fastjson.JSONObject;
import com.alibaba.fastjson.TypeReference;
import com.glxp.mipsdl.admin.client.BaseHttpClient;
import com.glxp.mipsdl.admin.config.ThirdSysConfig;
import com.glxp.mipsdl.admin.dao.phxyy.BasicThirdSysDetailDao;
import com.glxp.mipsdl.admin.entity.phxyy.BasicThirdSysBusApiEntity;
import com.glxp.mipsdl.admin.entity.phxyy.BasicThirdSysDetailEntity;
import com.glxp.mipsdl.admin.req.*;
import com.glxp.mipsdl.admin.res.phxyy.BussinessOriginTypeResponse;
import com.glxp.mipsdl.admin.service.phxyy.BasicThirdSysBusApiService;
import com.glxp.mipsdl.admin.service.phxyy.BussinessOriginTypeService;
import com.glxp.mipsdl.admin.util.HttpClient;
import com.glxp.mipsdl.common.res.BaseResponse;
import com.glxp.mipsdl.common.util.ResultVOUtils;
import org.springframework.http.HttpHeaders;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;

/**
 * 平和县医院对接
 */
@Service
public class PhxyyClient implements BaseHttpClient {

    @Resource
    private ThirdSysConfig thirdSysConfig;


    public HttpHeaders getHeaders() {
        HttpHeaders headers = new HttpHeaders();
        headers.add("Content-Type", "application/json");
        headers.add("api_key", thirdSysConfig.getThirdSysConfig().getApikey());
        headers.add("secret_key", thirdSysConfig.getThirdSysConfig().getSecretkey());
        return headers;
    }

    @Resource
    private BasicThirdSysBusApiService basicThirdSysBusApiService;
    @Resource
    private BussinessOriginTypeService bussinessOriginTypeService;
    @Resource
    private BasicThirdSysDetailDao basicThirdSysDetailDao;

    @Override
    public BaseResponse getUnit(UdiwmsUnitRequest unitRequest) {
        BasicThirdSysDetailEntity basicThirdSysDetailEntity = basicThirdSysDetailDao.selectByKey("corpUrl", unitRequest.getThirdSys());
        String response = HttpClient.postJson(thirdSysConfig.getThirdSysConfig().getThirdSysUrl() + basicThirdSysDetailEntity.getValue(), unitRequest, getHeaders());
        BaseResponse baseResponse =
                JSONObject.parseObject(response, new TypeReference<BaseResponse>() {
                });
        return baseResponse;
    }

    @Override
    public BaseResponse getProducts(UdiwmsProductRequest udiwmsProductRequest) {
        BasicThirdSysDetailEntity basicThirdSysDetailEntity = basicThirdSysDetailDao.selectByKey("piQueryUrl", udiwmsProductRequest.getThirdSys());
        String response = HttpClient.postJson(thirdSysConfig.getThirdSysConfig().getThirdSysUrl() + basicThirdSysDetailEntity.getValue(), udiwmsProductRequest, getHeaders());
        BaseResponse baseResponse =
                JSONObject.parseObject(response, new TypeReference<BaseResponse>() {
                });
        return baseResponse;
    }

    @Override
    public BaseResponse getOrderTypes(UdiwmsBusTypeRequest udiwmsBusTypeRequest) {
        BasicThirdSysDetailEntity basicThirdSysDetailEntity = basicThirdSysDetailDao.selectByKey("busTypeQueryUrl", udiwmsBusTypeRequest.getThirdSys());
        String response = HttpClient.postJson(thirdSysConfig.getThirdSysConfig().getThirdSysUrl() + basicThirdSysDetailEntity.getValue(), udiwmsBusTypeRequest, getHeaders());
        BaseResponse baseResponse =
                JSONObject.parseObject(response, new TypeReference<BaseResponse>() {
                });
        return baseResponse;
    }

    @Override
    public BaseResponse getOrders(UdiwmsOrderRequest udiwmsOrderRequest) {
        if (StrUtil.isEmpty(udiwmsOrderRequest.getBillType())) {
            return ResultVOUtils.error(500, "单据类型不能未空");
        }
        if (StrUtil.isEmpty(udiwmsOrderRequest.getThirdSys())) {
            return ResultVOUtils.error(500, "第三方系统ID不能为空");
        }
        BussinessOriginTypeResponse bussinessOriginTypeResponse = bussinessOriginTypeService.findByKey(udiwmsOrderRequest.getBillType(), udiwmsOrderRequest.getThirdSys());
        udiwmsOrderRequest.setBillType(bussinessOriginTypeResponse.getThirdAction());
        BasicThirdSysBusApiEntity basicThirdSysBusApiEntity = basicThirdSysBusApiService.selectByKey(bussinessOriginTypeResponse.getThirdAction(), bussinessOriginTypeResponse.getThirdSys(), 1);
        String response = HttpClient.postJson(thirdSysConfig.getThirdSysConfig().getThirdSysUrl() + basicThirdSysBusApiEntity.getUrl(), udiwmsOrderRequest, getHeaders());
        BaseResponse baseResponse =
                JSONObject.parseObject(response, new TypeReference<BaseResponse>() {
                });
        return baseResponse;
    }

    @Override
    public BaseResponse submitOrders(UdiwmsOrderRequest udiwmsOrderRequest) {
        if (StrUtil.isEmpty(udiwmsOrderRequest.getBillType())) {
            return ResultVOUtils.error(500, "单据类型不能未空");
        }
        if (StrUtil.isEmpty(udiwmsOrderRequest.getThirdSys())) {
            return ResultVOUtils.error(500, "第三方系统ID不能为空");
        }
        BasicThirdSysDetailEntity basicThirdSysDetailEntity = basicThirdSysDetailDao.selectByKey("orderSubmitUrl", udiwmsOrderRequest.getThirdSys());
        String response = HttpClient.postJson(thirdSysConfig.getThirdSysConfig().getThirdSysUrl() + basicThirdSysDetailEntity.getValue(), udiwmsOrderRequest, getHeaders());
        BaseResponse baseResponse =
                JSONObject.parseObject(response, new TypeReference<BaseResponse>() {
                });
        return baseResponse;
    }

    @Override
    public BaseResponse getInvProducts(UdiwmsOnhandRequest udiwmsOnhandRequest) {
        BasicThirdSysDetailEntity basicThirdSysDetailEntity = basicThirdSysDetailDao.selectByKey("invPiUrl", udiwmsOnhandRequest.getThirdSys());
        String response = HttpClient.postJson(thirdSysConfig.getThirdSysConfig().getThirdSysUrl() + basicThirdSysDetailEntity.getValue(), udiwmsOnhandRequest, getHeaders());
        BaseResponse baseResponse =
                JSONObject.parseObject(response, new TypeReference<BaseResponse>() {
                });
        return baseResponse;
    }

    @Override
    public BaseResponse getWarehouse(UdiwmsWarehouseRequest udiwmsWarehouseRequest) {
        BasicThirdSysDetailEntity basicThirdSysDetailEntity = basicThirdSysDetailDao.selectByKey("warehouseUrl", udiwmsWarehouseRequest.getThirdSys());
        String response = HttpClient.postJson(thirdSysConfig.getThirdSysConfig().getThirdSysUrl() + basicThirdSysDetailEntity.getValue(), udiwmsWarehouseRequest, getHeaders());
        BaseResponse baseResponse =
                JSONObject.parseObject(response, new TypeReference<BaseResponse>() {
                });
        return baseResponse;
    }
}
