package com.glxp.mipsdl.admin.client.http;

import cn.hutool.core.collection.CollUtil;
import cn.hutool.core.date.DateUtil;
import cn.hutool.core.util.StrUtil;
import com.glxp.mipsdl.admin.req.*;
import com.glxp.mipsdl.admin.res.system.UdiwmsWarehouseResponse;
import com.glxp.mipsdl.admin.res.system.*;
import com.glxp.mipsdl.admin.util.CustomUtil;
import com.glxp.mipsdl.common.res.BaseResponse;
import com.glxp.mipsdl.common.util.ResultVOUtils;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;

import java.math.BigDecimal;
import java.util.*;
import java.util.concurrent.atomic.AtomicInteger;

/**
 * 测试客户端，用于模拟测试数据
 */
@Slf4j
@Service
public class TestClient {


    /**
     * 查询往来单位信息
     *
     * @param testUnitRequest
     * @return
     */
    public BaseResponse getUnit(UdiwmsUnitRequest testUnitRequest) {
        if (null == testUnitRequest || StrUtil.isBlank(testUnitRequest.getThirdSys())) {
            return ResultVOUtils.error(500, "第三方系统ID不能为空");
        }
        List<UdiwmsUnitResponse> unitResponses = new ArrayList<>();
        AtomicInteger unitId = new AtomicInteger(2468);
        for (int i = 0; i < 10; i++) {
            UdiwmsUnitResponse response = new UdiwmsUnitResponse();
            response.setUnitId(String.valueOf(unitId.get()));
            unitId.addAndGet(1);
            response.setName("福建省诏安县医院");
            response.setSpell("ZAXYY");
            response.setAddr("诏安县南诏镇江厝前路65号");
            response.setCreditNo("123506244897495930");
            response.setContact("沈主任");
            response.setMobile("13306961860");
            unitResponses.add(response);
        }
        return ResultVOUtils.success(unitResponses);
    }

    /**
     * 查询产品信息
     *
     * @param udiwmsProductRequest
     * @return
     */
    public BaseResponse getProducuts(UdiwmsProductRequest udiwmsProductRequest) {
        if (null == udiwmsProductRequest || StrUtil.isBlank(udiwmsProductRequest.getThirdSys())) {
            return ResultVOUtils.error(500, "第三方系统ID不能为空");
        }
        List<UdiwmsProductInfoResponse> productInfoResponses = new ArrayList<>();
        for (int i = 0; i < 10; i++) {
            UdiwmsProductInfoResponse response = UdiwmsProductInfoResponse.builder()
                    .code("6555")
                    .name("下肢直型锁定钢板")
                    .measname("块")
                    .spec("12孔")
                    .model("12孔")
                    .registerNo("20153461024")
                    .manufactory("江苏艾迪尔")
                    .supName("南昌必理商贸有限公司")
                    .cplb("产品类别")
                    .flbm("分类编码")
                    .qxlb("器械类别")
                    .ybbm("医保编码")
                    .sptm("商品条码")
                    .tyshxydm("注册人社会信用号")
                    .zczbhhzbapzbh("注册证 备案证号")
                    .ylqxzcrbarmc("注册/备案人名称")
                    .ylqxzcrbarywmc("注册/备案人英文名称")
                    .cpms("产品描述")
                    .spmc("商品名称")
                    .qtbm("其他编码")
                    .zczyxqz("注册证有效期截止时间")
                    .updateTime(new Date())
                    .build();

            productInfoResponses.add(response);
        }
        return ResultVOUtils.success(productInfoResponses);
    }

    /**
     * 获取订单信息接口
     *
     * @param udiwmsOrderRequest
     * @return
     */
    public BaseResponse getOrders(UdiwmsOrderRequest udiwmsOrderRequest) {
        if (null == udiwmsOrderRequest || StrUtil.isBlank(udiwmsOrderRequest.getThirdSys())) {
            return ResultVOUtils.error(500, "第三方系统ID不能为空");
        }
        UdiwmsOrderResponse udiwmsOrderResponse = new UdiwmsOrderResponse();
        udiwmsOrderResponse.setBillNo("SP2022031376813");
        udiwmsOrderResponse.setStartDate("2022-03-13");
        udiwmsOrderResponse.setStartDate("2022-03-20");
        udiwmsOrderResponse.setBillFlag("单据状态");
        udiwmsOrderResponse.setBillType("ST54467264148");
        udiwmsOrderResponse.setBilldate("2022-03-13");
        udiwmsOrderResponse.setCreateUser("沈先生");
        udiwmsOrderResponse.setReviewUser("沈先生");
        udiwmsOrderResponse.setAddress("福建省厦门市集美区");
        udiwmsOrderResponse.setLinkMan("沈先生");
        udiwmsOrderResponse.setLinkTel("13306961860");
        List<UdiwmsOrderResponse.SubErpOrder> subErpOrders = new ArrayList<>();
        for (int i = 0; i < 3; i++) {
            UdiwmsOrderResponse.SubErpOrder subErpOrder = new UdiwmsOrderResponse.SubErpOrder();
            subErpOrder.setDetailId(CustomUtil.getId());
            subErpOrder.setCorpName("福建片仔癀诊断技术有限公司");
            subErpOrder.setBatchNo(CustomUtil.getUUId());
            subErpOrder.setProductDate(DateUtil.formatDate(DateUtil.yesterday()));
            subErpOrder.setExpireDate(DateUtil.formatDate(DateUtil.tomorrow()));
            subErpOrder.setCount(10);
            subErpOrder.setPrice(BigDecimal.valueOf(1000, 2));
            subErpOrder.setProductId("6555");
            subErpOrders.add(subErpOrder);
        }

        udiwmsOrderResponse.setDetailList(subErpOrders);
        return ResultVOUtils.success(udiwmsOrderResponse);
    }


    public BaseResponse getBusType(UdiwmsBusTypeRequest udiwmsBusTypeRequest) {
        if (null == udiwmsBusTypeRequest) {
            return ResultVOUtils.error(500, "参数不能未空");
        }
        List<UdiwmsBusTypeResponse> udiwmsBusTypeResponses = new ArrayList<>();
        UdiwmsBusTypeResponse udiwmsBusTypeResponse = new UdiwmsBusTypeResponse();
        udiwmsBusTypeResponse.setId("1");
        udiwmsBusTypeResponse.setCode("cgrk");
        udiwmsBusTypeResponse.setName("采购入库单");
        udiwmsBusTypeResponse.setRemark("测试");
        udiwmsBusTypeResponses.add(udiwmsBusTypeResponse);
        UdiwmsBusTypeResponse udiwmsBusTypeResponse2 = new UdiwmsBusTypeResponse();
        udiwmsBusTypeResponse2.setId("2");
        udiwmsBusTypeResponse2.setCode("syck");
        udiwmsBusTypeResponse2.setName("使用出库单");
        udiwmsBusTypeResponse2.setRemark("测试");
        udiwmsBusTypeResponses.add(udiwmsBusTypeResponse2);
        udiwmsBusTypeResponses.add(udiwmsBusTypeResponse);
        udiwmsBusTypeResponses.add(udiwmsBusTypeResponse2);

        return ResultVOUtils.success(udiwmsBusTypeResponses);
    }

    /**
     * 新增订单
     *
     * @param udiwmsOrderRequest
     * @return
     */
    public BaseResponse addOrders(UdiwmsOrderRequest udiwmsOrderRequest) {
        Map<String, Object> verifyResult = verifyOrderParams(udiwmsOrderRequest);
        boolean flag = (boolean) verifyResult.get("flag");
        if (!flag) {
            return ResultVOUtils.error(500, verifyResult.get("msg").toString());
        }
        return ResultVOUtils.success(CustomUtil.getId());
    }

    /**
     * 校验单据参数
     *
     * @param udiwmsOrderRequest
     * @return
     */
    private Map<String, Object> verifyOrderParams(UdiwmsOrderRequest udiwmsOrderRequest) {
        boolean flag = true;
        String msg = "";
        if (null == udiwmsOrderRequest) {
            flag = false;
            msg = "单据数据不能为空";
        } else if (StrUtil.isBlank(udiwmsOrderRequest.getThirdSys())) {
            flag = false;
            msg = "第三方系统ID不能为空";
        } else if (StrUtil.isBlank(udiwmsOrderRequest.getBillDate()) || StrUtil.isBlank(udiwmsOrderRequest.getBillFlag()) || StrUtil.isBlank(udiwmsOrderRequest.getCorpName())
                || StrUtil.isBlank(udiwmsOrderRequest.getCorpId()) || StrUtil.isBlank(udiwmsOrderRequest.getBillType()) || StrUtil.isBlank(udiwmsOrderRequest.getStatus())
                || StrUtil.isBlank(udiwmsOrderRequest.getStatus()) || CollUtil.isEmpty(udiwmsOrderRequest.getItems())) {
            flag = false;
            msg = "订单关键参数缺失或错误";
        } else {
            List<UdiwmsOrderDetail> items = udiwmsOrderRequest.getItems();
            for (UdiwmsOrderDetail item : items) {
                if (StrUtil.isBlank(item.getProductId()) || StrUtil.isBlank(item.getProductName()) || null == item.getPrice()
                        || null == item.getCount() || 0 >= item.getPrice().compareTo(BigDecimal.ZERO) || 0 >= item.getCount()
                        || StrUtil.isBlank(item.getProductDate()) || StrUtil.isBlank(item.getStandard())) {
                    flag = false;
                    msg = "单据详情数据缺失";
                    break;
                }
            }
        }
        Map<String, Object> map = new HashMap<>(2);
        map.put("flag", flag);
        map.put("msg", msg);
        return map;
    }

    /**
     * 修改单据信息
     *
     * @param udiwmsOrderRequest
     * @return
     */
    public BaseResponse editOrder(UdiwmsOrderRequest udiwmsOrderRequest) {
        Map<String, Object> verifyResult = verifyOrderParams(udiwmsOrderRequest);
        boolean flag = (boolean) verifyResult.get("flag");
        if (!flag) {
            return ResultVOUtils.error(500, verifyResult.get("msg").toString());
        }
        if (StrUtil.isBlank(udiwmsOrderRequest.getBillNo())) {
            return ResultVOUtils.error(500, "单据号不能为空");
        }
        return ResultVOUtils.success(CustomUtil.getId());
    }

    /**
     * 查询库存产品信息
     *
     * @param udiwmsOnhandRequest
     * @return
     */
    public BaseResponse getEnvProduct(UdiwmsOnhandRequest udiwmsOnhandRequest) {
        if (null == udiwmsOnhandRequest || StrUtil.isBlank(udiwmsOnhandRequest.getThirdSys())) {
            return ResultVOUtils.error(500, "第三方系统ID不能为空");
        }
        List<UdiwmsInvProductResponse> list = new ArrayList<>();
        for (int i = 0; i < 3; i++) {
            UdiwmsInvProductResponse response = new UdiwmsInvProductResponse();
            response.setBatchNo("批次号");
            response.setInventoryCode("1");
            response.setInventoryName("总库");
            response.setWarehouseCode("1001");
            response.setWarehouseName("货位1");
            response.setProductDate(DateUtil.formatDate(DateUtil.yesterday()));
            response.setExpireDate(DateUtil.formatDate(DateUtil.tomorrow()));
            response.setProductName("下肢直型锁定钢板");
            response.setProductId("6555");
            response.setStandard("12孔");
            response.setRegisterNo("20153461024");
            response.setCount(10);
            response.setManufactory("江苏艾迪尔");
            response.setSupId("2001");
            response.setSupName("南昌必理商贸有限公司");
            list.add(response);
        }
        return ResultVOUtils.success(list);
    }

    public BaseResponse getWarehouse(UdiwmsWarehouseRequest udiwmsWarehouseRequest) {
        if (null == udiwmsWarehouseRequest || StrUtil.isBlank(udiwmsWarehouseRequest.getThirdSys())) {
            return ResultVOUtils.error(500, "第三方系统ID不能为空");
        }
        List<UdiwmsWarehouseResponse> list = new ArrayList<>();
        for (int i = 0; i < 3; i++) {
            UdiwmsWarehouseResponse response = new UdiwmsWarehouseResponse();
            response.setCode("1001");
            response.setName("总库");
            response.setRemark("备注");
            for (int j = 0; j < 3; j++) {
                UdiwmsWarehouseDetail detail = new UdiwmsWarehouseDetail();
                detail.setCode("100101");
                detail.setName("货位1");
                detail.setRemark("货位备注");
                response.getDetails().add(detail);
            }
        }
        return ResultVOUtils.success(list);
    }
}
