package com.glxp.mipsdl.admin.controller;

import com.glxp.mipsdl.admin.annotation.AuthRuleAnnotation;
import com.glxp.mipsdl.admin.client.http.TestClient;
import com.glxp.mipsdl.admin.client.http.UdPlatClient;
import com.glxp.mipsdl.admin.client.http.YyUCloud31Client;
import com.glxp.mipsdl.admin.client.http.PhxyyClient;
import com.glxp.mipsdl.admin.http.request.USignRequest;
import com.glxp.mipsdl.admin.req.*;
import com.glxp.mipsdl.common.enums.ResultEnum;
import com.glxp.mipsdl.common.res.BaseResponse;
import com.glxp.mipsdl.common.util.ResultVOUtils;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.validation.BindingResult;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;

@RestController
public class UdiWmsController {

    @Value("${ONLINE_VESRION_FLAG}")
    private String curFlag;
    @Resource
    YyUCloud31Client pzhzdClient;

    @Resource
    private TestClient testClient;

    @Resource
    private UdPlatClient udPlatClient;
    @Resource
    private PhxyyClient phxyyClient;

    //获取erp往来单位信息接口
    @AuthRuleAnnotation("")
    @PostMapping("/udiwms/erp/getUnits")
    public BaseResponse getUnits(@RequestBody UdiwmsUnitRequest testUnitRequest,
                                 BindingResult bindingResult) {
        if (bindingResult.hasErrors()) {
            return ResultVOUtils.error(ResultEnum.PARAM_VERIFY_FALL, bindingResult.getFieldError().getDefaultMessage());
        }
        if (curFlag.equals("YONGYOU_U8_V3.1")) {
            return pzhzdClient.getUnit(testUnitRequest);
        } else if (curFlag.equals("TEST")) {
            return testClient.getUnit(testUnitRequest);
        } else if (curFlag.equals("PHXYY")) {
            return phxyyClient.getUnit(testUnitRequest);
        } else
            return ResultVOUtils.error(500, "当前第三方系统不支持往来单位信息查询！");
    }

    //获取ERP产品信息接口
    @AuthRuleAnnotation("")
    @PostMapping("/udiwms/erp/getProducts")
    public BaseResponse getProducts(@RequestBody UdiwmsProductRequest udiwmsProductRequest) {
        if (curFlag.equals("YONGYOU_U8_V3.1")) {
            return pzhzdClient.getProducts(udiwmsProductRequest);
        } else if (curFlag.equals("YG_UDPLAT_V1.0")) {
            return udPlatClient.getProducts(udiwmsProductRequest);
        } else if (curFlag.equals("TEST")) {
            return testClient.getProducuts(udiwmsProductRequest);
        } else if (curFlag.equals("PHXYY")) {
            return phxyyClient.getProducts(udiwmsProductRequest);
        }
        return ResultVOUtils.error(500, "当前第三方系统不支持产品信息查询！");
    }

    @AuthRuleAnnotation("")
    @PostMapping("/udiwms/erp/getWarehouse")
    public BaseResponse getWarehouse(UdiwmsWarehouseRequest udiwmsWarehouseRequest) {
        if (curFlag.equals("YONGYOU_U8_V3.1")) {
            return pzhzdClient.getWarehouse(udiwmsWarehouseRequest);
        } else if (curFlag.equals("TEST")) {
            return testClient.getWarehouse(udiwmsWarehouseRequest);
        } else
            return ResultVOUtils.error(500, "当前第三方系统不支持仓库货位号查询！");
    }

    //获取ERP订单接口
    @AuthRuleAnnotation("")
    @PostMapping("/udiwms/erp/getOrders")
    public BaseResponse getOrders(@RequestBody UdiwmsOrderRequest udiwmsOrderRequest) {
        if (curFlag.equals("YONGYOU_U8_V3.1")) {
            return pzhzdClient.getOrders(udiwmsOrderRequest);
        } else if (curFlag.equals("TEST")) {
            return testClient.getOrders(udiwmsOrderRequest);
        } else
            return ResultVOUtils.error(500, "当前第三方系统不支持业务单据查询！");

    }


    //获取ERP单据类型接口
    @PostMapping("/udiwms/erp/getOrderType")
    public BaseResponse getOrderTypes(@RequestBody UdiwmsBusTypeRequest udiwmsBusTypeRequest) {
        if (curFlag.equals("TEST")) {
            return testClient.getBusType(udiwmsBusTypeRequest);
        } else if (curFlag.equals("PHXYY")) {
            return phxyyClient.getOrderTypes(udiwmsBusTypeRequest);
        } else
            return ResultVOUtils.error(500, "当前第三方系统不支持业务单据类型查询！");

    }

    //提交单据
    @AuthRuleAnnotation("")
    @PostMapping("/udiwms/erp/submitOrders")
    public BaseResponse submitOrders(@RequestBody UdiwmsOrderRequest udiwmsOrderRequest) {
        if (curFlag.equals("TEST")) {
            return testClient.addOrders(udiwmsOrderRequest);
        } else if (curFlag.equals("PHXYY")) {
            return phxyyClient.submitOrders(udiwmsOrderRequest);
        }
        return ResultVOUtils.error(500, "");
    }


    //新增单据
    @AuthRuleAnnotation("")
    @PostMapping("/udiwms/erp/addOrders")
    public BaseResponse addOrders(@RequestBody UdiwmsOrderRequest udiwmsOrderRequest) {
        if (curFlag.equals("TEST")) {
            return testClient.addOrders(udiwmsOrderRequest);
        }
        return ResultVOUtils.error(500, "未设置系统版本");
    }

    /**
     * 修改订单
     *
     * @param udiwmsOrderRequest
     * @return
     */
    @AuthRuleAnnotation("")
    @PostMapping("/udiwms/erp/editOrder")
    public BaseResponse editOrder(@RequestBody UdiwmsOrderRequest udiwmsOrderRequest) {
        if (curFlag.equals("TEST")) {
            return testClient.editOrder(udiwmsOrderRequest);
        }
        return ResultVOUtils.success("修改成功");
    }

    //获取库存产品基本信息（批次号，生产日期，失效日期，仓位号）
    @PostMapping("/udiwms/erp/inv/getEnvProduct")
    public BaseResponse getEnvProduct(@RequestBody UdiwmsOnhandRequest udiwmsOnhandRequest) {
        if (curFlag.equals("YONGYOU_U8_V3.1")) {
            return pzhzdClient.getInvProducts(udiwmsOnhandRequest);
        } else if (curFlag.equals("TEST")) {
            return testClient.getEnvProduct(udiwmsOnhandRequest);
        } else
            return ResultVOUtils.error(500, "未设置系统版本！");

    }


    //修改ERP订单接口
    @PostMapping("/udiwms/erp/modifyBill")
    public BaseResponse modifyBill(@RequestBody UdiwmsPostBillRequest udiwmsPostBillRequest) {
        if (curFlag.equals("YONGYOU_U8_V3.1")) {
            return pzhzdClient.modifyBill(udiwmsPostBillRequest);
        } else
            return ResultVOUtils.error(500, "未设置系统版本！");

    }

    //签字ERP订单接口
    @PostMapping("/udiwms/erp/signBill")
    public BaseResponse signBill(@RequestBody USignRequest signRequest) {
        if (curFlag.equals("YONGYOU_U8_V3.1")) {
            return pzhzdClient.signBill(signRequest);
        } else
            return ResultVOUtils.error(500, "未设置系统版本！");

    }

    //获取现存量接口
    @GetMapping("/udiwms/erp/getOnhand")
    public BaseResponse getOnHand(@RequestBody UdiwmsOnhandRequest udiwmsOnhandRequest) {
        if (curFlag.equals("YONGYOU_U8_V3.1")) {
            return pzhzdClient.getOnHand(udiwmsOnhandRequest);
        } else
            return ResultVOUtils.error(500, "未设置系统版本！");

    }

    /**
     * 提交采购计划
     *
     * @param udiwmsOrderRequest
     * @return
     */
    @PostMapping("/udiwms/erp/order/postOrder")
    public BaseResponse postOrder(@RequestBody UdiwmsOrderRequest udiwmsOrderRequest) {
        if (curFlag.equals("YG_UDPLAT_V1.0")) {
            return udPlatClient.postOrder(udiwmsOrderRequest);
        }
        return ResultVOUtils.error(500, "未设置系统版本");
    }

}
